@@ -7,9 +7,9 @@ Author: J.S. Oishi <jsoishi@gmail.com>
 Affiliation: KIPAC/SLAC/Stanford
 Author: Britton Smith <brittonsmith@gmail.com>
 Affiliation: MSU
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2010 Matthew Turk.  All Rights Reserved.
+  Copyright (C) 2010-2011 Matthew Turk.  All Rights Reserved.
 
   This file is part of yt.
 
@@ -28,6 +28,9 @@ License:
 
 """
 
+from .absorption_spectrum.api import \
+    AbsorptionSpectrum
+
 from .coordinate_transformation.api import \
     spherical_regrid
 
@@ -76,7 +79,6 @@ from .hierarchy_subset.api import \
     ExtractedParameterFile
 
 from .level_sets.api import \
-    GridConsiderationQueue, \
     coalesce_join_tree, \
     identify_contours, \
     Clump, \
@@ -94,8 +96,8 @@ from .level_sets.api import \
     recursive_bottom_clumps, \
     clump_list_sort
 
-from .light_ray.api import \
-    LightRay
+#from .light_ray.api import \
+#    LightRay
 
 from .light_cone.api import \
     LightCone, \
