@@ -3,11 +3,11 @@ HOP-output data handling
 
 Author: Matthew Turk <matthewturk@gmail.com>
 Affiliation: KIPAC/SLAC/Stanford
-Author: Stephen Skory <stephenskory@yahoo.com>
+Author: Stephen Skory <s@skory.us>
 Affiliation: UCSD Physics/CASS
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2008-2009 Matthew Turk.  All Rights Reserved.
+  Copyright (C) 2008-2011 Matthew Turk.  All Rights Reserved.
 
   This file is part of yt.
 
@@ -228,7 +228,8 @@ class Halo(object):
         r"""Returns a sphere source.
 
         This will generate a new, empty sphere source centered on this halo,
-        with the maximum radius of the halo.
+        with the maximum radius of the halo. This can be used like any other
+        data container in yt.
         
         Parameters
         ----------
@@ -856,7 +857,7 @@ class LoadedHalo(Halo):
         # First get the list of fields from the first file. Not all fields
         # are saved all the time (e.g. creation_time, particle_type).
         mylog.info("Getting field %s from hdf5 halo particle files." % field)
-        f = h5py.File(fnames[0])
+        f = h5py.File(fnames[0], 'r')
         fields = f["Halo%08d" % halo].keys()
         # If we dont have this field, we can give up right now.
         if field not in fields: return None
@@ -866,14 +867,19 @@ class LoadedHalo(Halo):
         else:
             field_data = na.empty(size, dtype='float64')
         f.close()
+        # Apparently, there's a bug in h5py that was keeping the file pointer
+        # f closed, even though it's re-opened below. This del seems to fix
+        # that.
+        del f
         offset = 0
         for fname in fnames:
-            f = h5py.File(fname)
+            f = h5py.File(fname, 'r')
             this = f["Halo%08d" % halo][field][:]
             s = this.size
             field_data[offset:offset+s] = this
             offset += s
             f.close()
+            del f
         return field_data
         
     def center_of_mass(self):
@@ -969,6 +975,34 @@ class LoadedHalo(Halo):
         """
         return self.max_radius
 
+    def get_sphere(self):
+        r"""Returns a sphere source.
+
+        This will generate a new, empty sphere source centered on this halo,
+        with the maximum radius of the halo. This can be used like any other
+        data container in yt.
+        
+        Parameters
+        ----------
+        center_of_mass : bool, optional
+            True chooses the center of mass when calculating the maximum radius.
+            False chooses from the maximum density location for HOP halos
+            (it has no effect for FOF halos).
+            Default = True.
+        
+        Returns
+        -------
+        sphere : `yt.data_objects.api.AMRSphereBase`
+            The empty data source.
+
+        Examples
+        --------
+        >>> sp = halos[0].get_sphere()
+        """
+        cen = self.center_of_mass()
+        r = self.maximum_radius()
+        return self.pf.h.sphere(cen, r)
+
 class HaloList(object):
 
     _fields = ["particle_position_%s" % ax for ax in 'xyz']
@@ -1332,7 +1366,11 @@ class LoadedHaloList(HaloList):
         locations = []
         for line in lines:
             line = line.split()
-            locations.append(line[1:])
+            # Prepend the hdf5 file names with the full path.
+            temp = []
+            for item in line[1:]:
+                temp.append(self.pf.fullpath + '/' + item)
+            locations.append(temp)
         lines.close()
         return locations
 
@@ -2211,4 +2249,4 @@ class LoadHaloes(GenericHaloFinder, LoadedHaloList):
         LoadedHaloList.__init__(self, pf, self.basename)
 
 
-        
\ No newline at end of file
+        
