@@ -1,11 +1,11 @@
 """
 halo_mass_function - Halo Mass Function and supporting functions.
 
-Author: Stephen Skory <sskory@physics.ucsd.edu>
+Author: Stephen Skory <s@skory.us>
 Affiliation: UC San Diego / CASS
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2008-2009 Stephen Skory (and others).  All Rights Reserved.
+  Copyright (C) 2008-2011 Stephen Skory (and others).  All Rights Reserved.
 
   This file is part of yt.
 
@@ -323,8 +323,8 @@ class HaloMassFcn(ParallelAnalysisInterface):
             dn_M_z = -1.0 / thissigma * dsigmadm * rho0 / self.massarray[i] * \
             self.multiplicityfunction(thissigma)*(self.massarray[i+1] - self.massarray[i]);
 
-            # scale by h^4 to get rid of all factors of h
-            dn_M_z *= math.pow(self.hubble0, 4.0);
+            # scale by h^3 to get rid of all factors of h
+            dn_M_z *= math.pow(self.hubble0, 3.0);
             
             # keep track of cumulative number density
             if dn_M_z > 1.0e-20:
