@@ -1,11 +1,11 @@
 """
 MergerTree class and member functions.
 
-Author: Stephen Skory <sskory@physics.ucsd.edu>
+Author: Stephen Skory <s@skory.us>
 Affiliation: CASS/UC San Diego, CA
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2008-2010 Stephen Skory.  All Rights Reserved.
+  Copyright (C) 2008-2011 Stephen Skory.  All Rights Reserved.
 
   This file is part of yt.
 
