@@ -3,9 +3,9 @@ Halo filters to be used with the HaloProfiler.
 
 Author: Britton Smith <brittons@origins.colorado.edu>
 Affiliation: CASA/University of CO, Boulder
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2008-2009 Britton Smith.  All Rights Reserved.
+  Copyright (C) 2008-2011 Britton Smith.  All Rights Reserved.
 
   This file is part of yt.
 
@@ -28,18 +28,56 @@ import numpy as na
 
 from yt.funcs import *
 
-def VirialFilter(profile,overdensity_field='ActualOverdensity',
-                 virial_overdensity=200.,must_be_virialized=True,
-                 virial_filters=[['TotalMassMsun','>=','1e14']],
-                 virial_quantities=['TotalMassMsun','RadiusMpc'],
-                 virial_index=None):
-    """
-    Filter halos by virial quantities.
+def VirialFilter(profile, overdensity_field='ActualOverdensity',
+                 virial_overdensity=200., must_be_virialized=True,
+                 virial_filters=[['TotalMassMsun', '>=','1e14']],
+                 virial_quantities=['TotalMassMsun', 'RadiusMpc'],
+                 virial_index=None, use_log=False):
+    r"""Filter halos by virial quantities.
+    
     Return values are a True or False whether the halo passed the filter, 
     along with a dictionary of virial quantities for the fields specified in 
     the virial_quantities keyword.  Thresholds for virial quantities are 
-    given with the virial_filters keyword in the following way: 
+    given with the virial_filters keyword in the following way:
     [field, condition, value].
+    
+    This is typically used as part of a call to `add_halo_filter`.
+    
+    Parameters
+    ----------
+    overdensity_field : string
+        The field used for interpolation with the 
+        specified critical value given with 'virial_overdensity'.  
+        Default='ActualOverdensity'.
+    virial_overdensity : float
+        The value used to determine the outer radius of the virialized halo.
+        Default: 200.
+    must_be_virialized : bool
+        If no values in the profile are above the 
+        value of virial_overdensity, the halo does not pass the filter.  
+        Default: True.
+    virial_filters : array_like
+        Conditional filters based on virial quantities 
+        given in the following way: [field, condition, value].  
+        Default: [['TotalMassMsun', '>=','1e14']].
+    virial_quantities : array_like
+        Fields for which interpolated values should 
+        be calculated and returned.  Default: ['TotalMassMsun', 'RadiusMpc'].
+    virial_index : array_like
+        If given as a list, the index of the radial profile 
+        which is used for interpolation is placed here.  Default: None.
+    use_log : bool
+        If True, interpolation is done in log space.  
+        Default: False.
+    
+    Examples
+    --------
+    >>> hp.add_halo_filter(HP.VirialFilter, must_be_virialized=True,
+                   overdensity_field='ActualOverdensity',
+                   virial_overdensity=200,
+                   virial_filters=[['TotalMassMsun','>=','1e14']],
+                   virial_quantities=['TotalMassMsun','RadiusMpc'])
+    
     """
 
     fields = deepcopy(virial_quantities)
@@ -49,9 +87,7 @@ def VirialFilter(profile,overdensity_field='ActualOverdensity',
             fields.append(vfilter[0])
     
     overDensity = []
-    temp_profile = {}
-    for field in fields:
-        temp_profile[field] = []
+    temp_profile = dict((field, []) for field in fields)
 
     for q in range(len(profile[overdensity_field])):
         good = True
@@ -67,9 +103,11 @@ def VirialFilter(profile,overdensity_field='ActualOverdensity',
             for field in fields:
                 temp_profile[field].append(profile[field][q])
 
-    virial = {}
-    for field in fields:
-        virial[field] = 0.0
+    if use_log:
+        for field in temp_profile.keys():
+            temp_profile[field] = na.log10(temp_profile[field])
+
+    virial = dict((field, 0.0) for field in fields)
 
     if (not (na.array(overDensity) >= virial_overdensity).any()) and \
             must_be_virialized:
@@ -85,8 +123,8 @@ def VirialFilter(profile,overdensity_field='ActualOverdensity',
     elif (overDensity[-1] >= virial_overdensity):
         index = -2
     else:
-        for q in (na.arange(len(overDensity)-2))+2:
-            if (overDensity[q] < virial_overdensity):
+        for q in (na.arange(len(overDensity),0,-1)-1):
+            if (overDensity[q] < virial_overdensity) and (overDensity[q-1] >= virial_overdensity):
                 index = q - 1
                 break
 
@@ -104,13 +142,20 @@ def VirialFilter(profile,overdensity_field='ActualOverdensity',
                 temp_profile[field][index]
             virial[field] = value
 
+    if use_log:
+        for field in virial.keys():
+            virial[field] = na.power(10, virial[field])
+
     for vfilter in virial_filters:
         if eval("%s %s %s" % (virial[vfilter[0]],vfilter[1],vfilter[2])):
-            mylog.debug("(%s %s %s) returned True for %s." % (vfilter[0],vfilter[1],vfilter[2],virial[vfilter[0]]))
+            mylog.debug("(%s %s %s) returned True for %s." % \
+                            (vfilter[0],vfilter[1],vfilter[2],virial[vfilter[0]]))
             continue
         else:
-            mylog.debug("(%s %s %s) returned False for %s." % (vfilter[0],vfilter[1],vfilter[2],virial[vfilter[0]]))
+            mylog.debug("(%s %s %s) returned False for %s." % \
+                            (vfilter[0],vfilter[1],vfilter[2],virial[vfilter[0]]))
             return [False, {}]
 
-    return [True, dict((q,virial[q]) for q in virial_quantities)]
+    return [True, dict((("%s_%s" % (q, virial_overdensity)), virial[q])
+                       for q in virial_quantities)]
 
