@@ -3,9 +3,9 @@ LightCone class and member functions.
 
 Author: Britton Smith <brittons@origins.colorado.edu>
 Affiliation: CASA/University of CO, Boulder
-Homepage: http://yt.enzotools.org/
+Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2008-2009 Britton Smith.  All Rights Reserved.
+  Copyright (C) 2008-2011 Britton Smith.  All Rights Reserved.
 
   This file is part of yt.
 
@@ -49,25 +49,29 @@ class LightCone(EnzoSimulation):
                  set_parameters=None, output_dir='LC', output_prefix='LightCone', **kwargs):
         """
         Initialize a LightCone object.
-        :param initial_redshift (float): the initial (highest) redshift for the light cone.  Default: 1.0.
-        :param final_redshift (float): the final (lowest) redshift for the light cone.  Default: 0.0.
+        :param initial_redshift (float): the initial (highest) redshift for the light cone.  
+        Default: 1.0.
+        :param final_redshift (float): the final (lowest) redshift for the light cone.  
+        Default: 0.0.
         :param observer_redshift (float): the redshift of the observer.  Default: 0.0.
-        :param field_of_view_in_arcminutes (float): the field of view of the image in units of arcminutes.  
-               Default: 600.0.
-        :param image_resolution_in_arcseconds (float): the size of each image pixel in units of arcseconds.  
-               Default: 60.0.
-                             :param use_minimum_datasets (bool): if True, the minimum number of datasets is used to connect the 
-               initial and final redshift.  If false, the light cone solution will contain as many entries 
-               as possible within the redshift interval.  Default: True.
-        :param deltaz_min (float): specifies the minimum :math:`\Delta z` between consecutive datasets in 
-               the returned list.  Default: 0.0.
-        :param minimum_coherent_box_fraction (float): used with use_minimum_datasets set to False, this 
-               parameter specifies the fraction of the total box size to be traversed before rerandomizing 
-               the projection axis and center.  This was invented to allow light cones with thin slices to 
-               sample coherent large scale structure, but in practice does not work so well.  Try setting 
-               this parameter to 1 and see what happens.  Default: 0.0.
-        :param set_parameters (dict): dictionary of parameters to attach to pf.parameters.  Default: None.
-        :param output_dir (str): the directory in which images and data files will be written.  Default: 'LC'.
+        :param field_of_view_in_arcminutes (float): the field of view of the image in units of 
+        arcminutes.  Default: 600.0.
+        :param image_resolution_in_arcseconds (float): the size of each image pixel in units of 
+        arcseconds.  Default: 60.0.
+        :param use_minimum_datasets (bool): if True, the minimum number of datasets is used to 
+        connect the initial and final redshift.  If false, the light cone solution will contain 
+        as many entries as possible within the redshift interval.  Default: True.
+        :param deltaz_min (float): specifies the minimum :math:`\Delta z` between consecutive 
+        datasets in the returned list.  Default: 0.0.
+        :param minimum_coherent_box_fraction (float): used with use_minimum_datasets set to 
+        False, this parameter specifies the fraction of the total box size to be traversed before 
+        rerandomizing the projection axis and center.  This was invented to allow light cones with 
+        thin slices to sample coherent large scale structure, but in practice does not work so 
+        well.  Try setting this parameter to 1 and see what happens.  Default: 0.0.
+        :param set_parameters (dict): dictionary of parameters to attach to pf.parameters.  
+        Default: None.
+        :param output_dir (str): the directory in which images and data files will be written.  
+        Default: 'LC'.
         :param output_prefix (str): the prefix of all images and data files.  Default: 'LightCone'.
         """
 
@@ -118,12 +122,20 @@ class LightCone(EnzoSimulation):
                                                                 deltaz_min=self.deltaz_min)
 
     def calculate_light_cone_solution(self, seed=None, filename=None):
-        """
-        Create list of projections to be added together to make the light cone.
-        :param seed (int): the seed for the random number generator.  Any light cone solution 
-               can be reproduced by giving the same random seed.  Default: None (each solution 
-               will be distinct).
-        :param filename (str): if given, a text file detailing the solution will be written out.  Default: None.
+        r"""Create list of projections to be added together to make the light cone.
+
+        Several sentences providing an extended description. Refer to
+        variables using back-ticks, e.g. `var`.
+
+        Parameters
+        ----------
+        seed : int
+            The seed for the random number generator.  Any light cone solution
+            can be reproduced by giving the same random seed.  Default: None
+            (each solution will be distinct).
+        filename : string
+            If given, a text file detailing the solution will be written out.
+            Default: None.
         """
 
         # Don't use box coherence with maximum projection depths.
@@ -205,13 +217,17 @@ class LightCone(EnzoSimulation):
             self._save_light_cone_solution(filename=filename)
 
     def get_halo_mask(self, mask_file=None, map_file=None, **kwargs):
-        """
-        Gets a halo mask from a file or makes a new one.
-        :param mask_file (str): specify an hdf5 file to output the halo mask.
-        :param map_file (str): specify a text file to output the halo map 
-               (locations in image of halos).
-        """
+        r"""Gets a halo mask from a file or makes a new one.
 
+        Parameters
+        ----------
+        mask_file : string, optional
+            An HDF5 file to which to output the halo mask
+        map_file : string, optional
+            A text file to which to output the halo map (locations in the
+            images of the halos
+
+        """
         # Get halo map if map_file given.
         if map_file is not None and not os.path.exists(map_file):
             light_cone_halo_map(self, map_file=map_file, **kwargs)
@@ -236,22 +252,34 @@ class LightCone(EnzoSimulation):
     def project_light_cone(self, field, weight_field=None, apply_halo_mask=False, node=None,
                            save_stack=True, save_slice_images=False, cmap_name='algae', 
                            flatten_stack=False, photon_field=False):
-        """
-        Create projections for light cone, then add them together.
-        :param weight_field (str): the weight field of the projection.  This has the same meaning as in standard 
-               projections.  Default: None.
-        :param apply_halo_mask (bool): if True, a boolean mask is apply to the light cone projection.  See below for a 
-               description of halo masks.  Default: False.
-        :param node (str): a prefix to be prepended to the node name under which the projection data is serialized.  
-               Default: None.
-        :param save_stack (bool): if True, the unflatted light cone data including each individual slice is written to 
-               an hdf5 file.  Default: True.
-        :param save_slice_images (bool): save images for each individual projection slice.  Default: False.
-        :param cmap_name (str): color map for images.  Default: 'algae'.
-        :param flatten_stack (bool): if True, the light cone stack is continually flattened each time a slice is added 
-               in order to save memory.  This is generally not necessary.  Default: False.
-        :param photon_field (bool): if True, the projection data for each slice is decremented by 4 Pi R^2`, where R 
-               is the luminosity distance between the observer and the slice redshift.  Default: False.
+        r"""Create projections for light cone, then add them together.
+
+        Parameters
+        ----------
+        weight_field : str
+            the weight field of the projection.  This has the same meaning as
+            in standard projections.  Default: None.
+        apply_halo_mask : bool
+            if True, a boolean mask is apply to the light cone projection.  See
+            below for a description of halo masks.  Default: False.
+        node : string
+            a prefix to be prepended to the node name under which the
+            projection data is serialized.  Default: None.
+        save_stack : bool
+            if True, the unflatted light cone data including each individual
+            slice is written to an hdf5 file.  Default: True.
+        save_slice_images : bool
+            save images for each individual projection slice.  Default: False.
+        cmap_name : string
+            color map for images.  Default: 'algae'.
+        flatten_stack : bool
+            if True, the light cone stack is continually flattened each time a
+            slice is added in order to save memory.  This is generally not
+            necessary.  Default: False.
+        photon_field : bool
+            if True, the projection data for each slice is decremented by 4 Pi
+            R^2`, where R is the luminosity distance between the observer and
+            the slice redshift.  Default: False.
         """
 
         # Clear projection stack.
@@ -516,7 +544,7 @@ class LightCone(EnzoSimulation):
 
         output = h5py.File(filename, "a")
 
-        node_exists = field_node in output.listnames()
+        node_exists = field_node in output
 
         if node_exists:
             if over_write:
